==> gi-assets-algorithm-2.3.3.tgz: package/es/NodesClustering/Component.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { ReloadOutlined } from '@ant-design/icons';
import { kMeans } from '@antv/algorithm';
import { useContext } from '@antv/gi-sdk';
import { Button, Empty, InputNumber, Row, Col, Spin } from 'antd';
import { cloneDeep, isEqual } from 'lodash';
import React, { useEffect, useState } from 'react';
import ClustersTable from '../ClusterTable';
import './index.less';
import $i18n from '../i18n';
export var NodesClusteringAlgorithm;
(function (NodesClusteringAlgorithm) {
  NodesClusteringAlgorithm["KMeans"] = "k-means";
})(NodesClusteringAlgorithm || (NodesClusteringAlgorithm = {}));
export var DistanceType;
(function (DistanceType) {
  DistanceType["EuclideanDistance"] = "euclideanDistance";
})(DistanceType || (DistanceType = {}));
var NodesClustering = function NodesClustering(props) {
  var controlledValues = props.controlledValues,
    onOpen = props.onOpen;
  var context = useContext();
  var data = context.data,
    graph = context.graph,
    layout = context.layout,
    updateContext = context.updateContext,
    updateHistory = context.updateHistory;
  var _useState = useState(NodesClusteringAlgorithm.KMeans),
    _useState2 = _slicedToArray(_useState, 2),
    nodeClusteringAlgo = _useState2[0],
    setNodeClusteringAlgo = _useState2[1];
  var _useState3 = useState(null),
    _useState4 = _slicedToArray(_useState3, 2),
    resData = _useState4[0],
    setResData = _useState4[1];
  var _useState5 = useState({
      nodes: [],
      edges: []
    }),
    _useState6 = _slicedToArray(_useState5, 2),
    initData = _useState6[0],
    setInitData = _useState6[1];
  var _useState7 = useState(2),
    _useState8 = _slicedToArray(_useState7, 2),
    clusterK = _useState8[0],
    setClusterK = _useState8[1];
  var _useState9 = useState(DistanceType.EuclideanDistance),
    _useState10 = _slicedToArray(_useState9, 2),
    distanceType = _useState10[0],
    setDistanceType = _useState10[1];
  var _useState11 = useState(false),
    _useState12 = _slicedToArray(_useState11, 2),
    hasAnalysis = _useState12[0],
    setHasAnalysis = _useState12[1];
  var _useState13 = useState(false),
    _useState14 = _slicedToArray(_useState13, 2),
    loading = _useState14[0],
    setLoading = _useState14[1];
  var _useState15 = useState(null),
    _useState16 = _slicedToArray(_useState15, 2),
    focusNodeId = _useState16[0],
    setFocusNodeId = _useState16[1];
  var _useState17 = useState({
      nodes: [],
      edges: []
    }),
    _useState18 = _slicedToArray(_useState17, 2),
    prevData = _useState18[0],
    setPrevData = _useState18[1];
  var _useState19 = useState(layout),
    _useState20 = _slicedToArray(_useState19, 2),
    prevLayout = _useState20[0],
    setPrevLayout = _useState20[1];
  var getInitData = function getInitData() {
    if (!graph || graph.destroyed) {
      return {
        nodes: [],
        edges: []
      };
    }
    return {
      nodes: cloneDeep(graph.getNodes()).map(function (node) {
        return node.getModel();
      }),
      edges: cloneDeep(graph.getEdges()).map(function (edge) {
        return edge.getModel();
      })
    };
  };
  useEffect(function () {
    if (!graph || graph.destroyed) return;
    setInitData({
      //@ts-ignore
      nodes: cloneDeep(graph.getNodes()).map(function (node) {
        return node.getModel();
      }),
      //@ts-ignore
      edges: cloneDeep(graph.getEdges()).map(function (edge) {
        var model = edge.getModel();
        return Object.assign(Object.assign({}, model), {
          //@ts-ignore
          id: model.id || model.data.id
        });
      })
    });
  }, [data, graph]);
  /**
   * 受控参数变化，自动进行分析
   * e.g. ChatGPT，历史记录模版等
   */
  useEffect(function () {
    if (controlledValues) {
      var algorithm = controlledValues.algorithm,
        controlledClusterK = controlledValues.clusterK,
        controlledDistanceType = controlledValues.distanceType,
        controlledFocusNodeId = controlledValues.focusNodeId;
      setNodeClusteringAlgo(algorithm);
      setClusterK(controlledClusterK);
      setDistanceType(controlledDistanceType);
      onOpen === null || onOpen === void 0 ? void 0 : onOpen();
      onAnalyse();
      if (controlledFocusNodeId) {
        focusNodeAndHighlightHull(controlledFocusNodeId);
      }
    }
  }, [controlledValues]);
  var formatOriginData = function formatOriginData(_ref) {
    var _ref$nodes = _ref.nodes,
      nodes = _ref$nodes === void 0 ? [] : _ref$nodes,
      _ref$edges = _ref.edges,
      edges = _ref$edges === void 0 ? [] : _ref$edges;
    return {
      nodes: nodes.map(function (node) {
        var properties = Object.assign({}, node.data, node.data.properties);
        delete properties.id;
        return {
          id: node.id,
          label: node.label || node.data.label || node.data.name,
          properties: properties
        };
      }),
      edges: edges.map(function (edge) {
        return Object.assign(Object.assign({}, edge), {
          id: edge.id || edge.data.id
        });
      })
    };
  };
  var transDataWithCombo = function transDataWithCombo(graphData, clusters) {
    var comboNodeMap = {};
    clusters.forEach(function (cluster, index) {
      cluster.forEach(function (node) {
        comboNodeMap[node.id] = "gi-kmeans-combo-".concat(String(index));
      });
    });
    return {
      nodes: graphData === null || graphData === void 0 ? void 0 : graphData.nodes.map(function (node) {
        return Object.assign(Object.assign({}, node), {
          comboId: comboNodeMap[node.id],
          x: undefined,
          y: undefined
        });
      }),
      edges: graphData === null || graphData === void 0 ? void 0 : graphData.edges,
      combos: clusters.map(function (cluster, index) {
        return {
          id: "gi-kmeans-combo-".concat(String(index)),
          label: $i18n.get({
            id: 'gi-assets-algorithm.src.NodesClustering.Component.CategoryIndex',
            dm: '分类{index}'
          }, {
            index: index
          })
        };
      })
    };
  };
  var onAnalyse = function onAnalyse() {
    setHasAnalysis(true);
    setLoading(true);
    setTimeout(function () {
      var formatData = formatOriginData(data);
      switch (nodeClusteringAlgo) {
        case NodesClusteringAlgorithm.KMeans:
          if (!graph || graph.destroyed) {
            return;
          }
          var _kMeans = kMeans(formatData,
            //@ts-ignore
            clusterK,
            //@ts-ignore
            'properties', [], [], distanceType),
            clusters = _kMeans.clusters;
          setResData(formatData);
          var newData = transDataWithCombo(data, clusters);
          setPrevData(newData);
          updateContext(function (draft) {
            draft.data = newData;
          });
          break;
        default:
          break;
      }
      setLoading(false);
      updateHistory({
        componentId: 'NodesClustering',
        type: 'analyse',
        subType: $i18n.get({
          id: 'gi-assets-algorithm.src.NodesClustering.Component.NodeClustering',
          dm: '节点聚类'
        }),
        statement: $i18n.get({
          id: 'gi-assets-algorithm.src.NodesClustering.Component.AlgorithmNodeclusteringalgo',
          dm: '算法 {nodeClusteringAlgo}'
        }, {
          nodeClusteringAlgo: nodeClusteringAlgo
        }),
        success: true,
        params: {
          algorithm: nodeClusteringAlgo,
          clusterK: clusterK,
          distanceType: distanceType,
          focusNodeId: focusNodeId
        }
      });
    }, 100);
  };
  var renderResult = function renderResult() {
    var _a;
    if (!hasAnalysis) {
      return;
    }
    if (loading) {
      return /*#__PURE__*/React.createElement(Spin, {
        spinning: true
      }, /*#__PURE__*/React.createElement("div", {
        className: "kg-nodes-clustering-result-wrapper"
      }));
    }
    if (!((_a = resData === null || resData === void 0 ? void 0 : resData.nodes) === null || _a === void 0 ? void 0 : _a.length)) {
      return /*#__PURE__*/React.createElement(Empty, {
        image: Empty.PRESENTED_IMAGE_SIMPLE,
        description: $i18n.get({
          id: 'gi-assets-algorithm.src.NodesClustering.Component.NoDataAvailable',
          dm: '暂无数据'
        })
      });
    }
    return /*#__PURE__*/React.createElement("div", {
      className: "nodes-clustering-result-wrapper"
    }, /*#__PURE__*/React.createElement("span", {
      className: "intelligent-analysis-title nodes-clustering-result-title"
    }, $i18n.get({
      id: 'gi-assets-algorithm.src.NodesClustering.Component.AnalysisResults',
      dm: '分析结果'
    })), /*#__PURE__*/React.createElement(ClustersTable, {
      data: resData,
      clusterTitle: $i18n.get({
        id: 'gi-assets-algorithm.src.NodesClustering.Component.Classification',
        dm: '分类'
      }),
      focusNodeAndHighlightHull: focusNodeAndHighlightHull
    }));
  };
  var clearActiveState = function clearActiveState() {
    if (focusNodeId) {
      var focusNode = graph.findById(focusNodeId);
      if (focusNode.hasState('active')) {
        graph.setItemState(focusNodeId, 'active', false);
      }
    }
  };
  var focusNodeAndHighlightHull = function focusNodeAndHighlightHull(nodeId) {
    var focusClusterId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    clearActiveState();
    var node = graph.findById(nodeId);
    if (node) {
      graph.setItemState(node, 'active', true);
      setFocusNodeId(nodeId);
    }
  };
  var reset = function reset() {
    setResData({
      nodes: [],
      edges: []
    });
    setNodeClusteringAlgo(NodesClusteringAlgorithm.KMeans);
    setClusterK(2);
    clearActiveState();
    updateContext(function (draft) {
      draft.data = initData;
      draft.layout = prevLayout;
    });
  };
  useEffect(function () {
    if (!isEqual(data, prevData)) {
      // @ts-ignore
      setInitData(getInitData());
      // 源数据变化，清空当前结果
      setResData({
        nodes: [],
        edges: []
      });
      clearActiveState();
      updateContext(function (draft) {
        draft.layout = prevLayout;
      });
    }
    // @ts-ignore
    setPrevData(cloneDeep(data));
  }, [data, graph]);
  useEffect(function () {
    //@ts-ignore
    setInitData(getInitData());
    //@ts-ignore
    setPrevLayout(layout);
  }, []);
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-wrapper"
  }, /*#__PURE__*/React.createElement(Row, {
    justify: "space-between"
  }, /*#__PURE__*/React.createElement(Col, {
    span: 21
  }, /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-algo-title"
  }, /*#__PURE__*/React.createElement("h4", {
    className: "nodes-clustering-algo-title-name"
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.NodesclusteringalgorithmkmeansAlgorithm',
    dm: '{NodesClusteringAlgorithmKMeans}算法'
  }, {
    NodesClusteringAlgorithmKMeans: NodesClusteringAlgorithm.KMeans
  })), /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-algo-title-tip"
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.GatherNodesIntoKClusters',
    dm: '根据节点之间的距离将节点聚成K个簇'
  })))), /*#__PURE__*/React.createElement(Col, {
    span: 2,
    offset: 1,
    style: {
      lineHeight: '32px',
      textAlign: 'right'
    }
  }, /*#__PURE__*/React.createElement(ReloadOutlined, {
    onClick: reset
  }))), /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-algo-body"
  }, /*#__PURE__*/React.createElement("span", null, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.SetTheKValue',
    dm: '设置 K 值'
  })), /*#__PURE__*/React.createElement(InputNumber, {
    min: 1,
    value: clusterK,
    style: {
      margin: '10px 20px'
    },
    onChange: function onChange(value) {
      return setClusterK(value);
    }
  })), /*#__PURE__*/React.createElement(Button, {
    type: "primary",
    style: {
      width: '100%',
      marginTop: '12px'
    },
    loading: loading,
    onClick: onAnalyse
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.Analysis',
    dm: '分析'
  })), renderResult()));
};
export default NodesClustering;

==> gi-assets-algorithm-2.3.12.tgz: package/es/NodesClustering/Component.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { ReloadOutlined } from '@ant-design/icons';
import { kMeans } from '@antv/algorithm';
import { useContext } from '@antv/gi-sdk';
import { Button, Col, Empty, InputNumber, Row, Spin } from 'antd';
import { cloneDeep, isEqual } from 'lodash';
import React, { memo, useEffect, useState } from 'react';
import ClustersTable from '../ClusterTable';
import $i18n from '../i18n';
import './index.less';
export var NodesClusteringAlgorithm;
(function (NodesClusteringAlgorithm) {
  NodesClusteringAlgorithm["KMeans"] = "k-means";
})(NodesClusteringAlgorithm || (NodesClusteringAlgorithm = {}));
export var DistanceType;
(function (DistanceType) {
  DistanceType["EuclideanDistance"] = "euclideanDistance";
})(DistanceType || (DistanceType = {}));
var NodesClustering = function NodesClustering(props) {
  var controlledValues = props.controlledValues,
    onOpen = props.onOpen;
  var context = useContext();
  var data = context.data,
    graph = context.graph,
    layout = context.layout,
    updateContext = context.updateContext,
    updateHistory = context.updateHistory;
  var _useState = useState(NodesClusteringAlgorithm.KMeans),
    _useState2 = _slicedToArray(_useState, 2),
    nodeClusteringAlgo = _useState2[0],
    setNodeClusteringAlgo = _useState2[1];
  var _useState3 = useState(null),
    _useState4 = _slicedToArray(_useState3, 2),
    resData = _useState4[0],
    setResData = _useState4[1];
  var _useState5 = useState({
      nodes: [],
      edges: []
    }),
    _useState6 = _slicedToArray(_useState5, 2),
    initData = _useState6[0],
    setInitData = _useState6[1];
  var _useState7 = useState(2),
    _useState8 = _slicedToArray(_useState7, 2),
    clusterK = _useState8[0],
    setClusterK = _useState8[1];
  var _useState9 = useState(DistanceType.EuclideanDistance),
    _useState10 = _slicedToArray(_useState9, 2),
    distanceType = _useState10[0],
    setDistanceType = _useState10[1];
  var _useState11 = useState(false),
    _useState12 = _slicedToArray(_useState11, 2),
    hasAnalysis = _useState12[0],
    setHasAnalysis = _useState12[1];
  var _useState13 = useState(false),
    _useState14 = _slicedToArray(_useState13, 2),
    loading = _useState14[0],
    setLoading = _useState14[1];
  var _useState15 = useState(null),
    _useState16 = _slicedToArray(_useState15, 2),
    focusNodeId = _useState16[0],
    setFocusNodeId = _useState16[1];
  var _useState17 = useState({
      nodes: [],
      edges: []
    }),
    _useState18 = _slicedToArray(_useState17, 2),
    prevData = _useState18[0],
    setPrevData = _useState18[1];
  var _useState19 = useState(layout),
    _useState20 = _slicedToArray(_useState19, 2),
    prevLayout = _useState20[0],
    setPrevLayout = _useState20[1];
  var getInitData = function getInitData() {
    if (!graph || graph.destroyed) {
      return {
        nodes: [],
        edges: []
      };
    }
    return {
      nodes: cloneDeep(graph.getNodes()).map(function (node) {
        return node.getModel();
      }),
      edges: cloneDeep(graph.getEdges()).map(function (edge) {
        return edge.getModel();
      })
    };
  };
  useEffect(function () {
    if (!graph || graph.destroyed) return;
    setInitData({
      //@ts-ignore
      nodes: cloneDeep(graph.getNodes()).map(function (node) {
        return node.getModel();
      }),
      //@ts-ignore
      edges: cloneDeep(graph.getEdges()).map(function (edge) {
        var model = edge.getModel();
        return Object.assign(Object.assign({}, model), {
          //@ts-ignore
          id: model.id || model.data.id
        });
      })
    });
  }, [data, graph]);
  /**
   * 受控参数变化，自动进行分析
   * e.g. ChatGPT，历史记录模版等
   */
  useEffect(function () {
    if (controlledValues) {
      var algorithm = controlledValues.algorithm,
        controlledClusterK = controlledValues.clusterK,
        controlledDistanceType = controlledValues.distanceType,
        controlledFocusNodeId = controlledValues.focusNodeId;
      setNodeClusteringAlgo(algorithm);
      setClusterK(controlledClusterK);
      setDistanceType(controlledDistanceType);
      onOpen === null || onOpen === void 0 ? void 0 : onOpen();
      onAnalyse();
      if (controlledFocusNodeId) {
        focusNodeAndHighlightHull(controlledFocusNodeId);
      }
    }
  }, [controlledValues]);
  var formatOriginData = function formatOriginData(_ref) {
    var _ref$nodes = _ref.nodes,
      nodes = _ref$nodes === void 0 ? [] : _ref$nodes,
      _ref$edges = _ref.edges,
      edges = _ref$edges === void 0 ? [] : _ref$edges;
    return {
      nodes: nodes.map(function (node) {
        var properties = Object.assign({}, node.data, node.data.properties);
        delete properties.id;
        return {
          id: node.id,
          label: node.label || node.data.label || node.data.name,
          properties: properties
        };
      }),
      edges: edges.map(function (edge) {
        return Object.assign(Object.assign({}, edge), {
          id: edge.id || edge.data.id
        });
      })
    };
  };
  var transDataWithCombo = function transDataWithCombo(graphData, clusters) {
    var comboNodeMap = {};
    clusters.forEach(function (cluster, index) {
      cluster.forEach(function (node) {
        comboNodeMap[node.id] = "gi-kmeans-combo-".concat(String(index));
      });
    });
    return {
      nodes: graphData === null || graphData === void 0 ? void 0 : graphData.nodes.map(function (node) {
        return Object.assign(Object.assign({}, node), {
          comboId: comboNodeMap[node.id],
          x: undefined,
          y: undefined
        });
      }),
      edges: graphData === null || graphData === void 0 ? void 0 : graphData.edges,
      combos: clusters.map(function (cluster, index) {
        return {
          id: "gi-kmeans-combo-".concat(String(index)),
          label: $i18n.get({
            id: 'gi-assets-algorithm.src.NodesClustering.Component.CategoryIndex',
            dm: '分类{index}'
          }, {
            index: index
          })
        };
      })
    };
  };
  var onAnalyse = function onAnalyse() {
    setHasAnalysis(true);
    setLoading(true);
    setTimeout(function () {
      var formatData = formatOriginData(data);
      switch (nodeClusteringAlgo) {
        case NodesClusteringAlgorithm.KMeans:
          if (!graph || graph.destroyed) {
            return;
          }
          var _kMeans = kMeans(formatData,
            //@ts-ignore
            clusterK,
            //@ts-ignore
            'properties', [], [], distanceType),
            clusters = _kMeans.clusters;
          setResData(formatData);
          var newData = transDataWithCombo(data, clusters);
          setPrevData(newData);
          updateContext(function (draft) {
            draft.data = newData;
          });
          break;
        default:
          break;
      }
      setLoading(false);
      updateHistory({
        componentId: 'NodesClustering',
        type: 'analyse',
        subType: $i18n.get({
          id: 'gi-assets-algorithm.src.NodesClustering.Component.NodeClustering',
          dm: '节点聚类'
        }),
        statement: $i18n.get({
          id: 'gi-assets-algorithm.src.NodesClustering.Component.AlgorithmNodeclusteringalgo',
          dm: '算法 {nodeClusteringAlgo}'
        }, {
          nodeClusteringAlgo: nodeClusteringAlgo
        }),
        success: true,
        params: {
          algorithm: nodeClusteringAlgo,
          clusterK: clusterK,
          distanceType: distanceType,
          focusNodeId: focusNodeId
        }
      });
    }, 100);
  };
  var renderResult = function renderResult() {
    var _a;
    if (!hasAnalysis) {
      return;
    }
    if (loading) {
      return /*#__PURE__*/React.createElement(Spin, {
        spinning: true
      }, /*#__PURE__*/React.createElement("div", {
        className: "kg-nodes-clustering-result-wrapper"
      }));
    }
    if (!((_a = resData === null || resData === void 0 ? void 0 : resData.nodes) === null || _a === void 0 ? void 0 : _a.length)) {
      return /*#__PURE__*/React.createElement(Empty, {
        image: Empty.PRESENTED_IMAGE_SIMPLE,
        description: $i18n.get({
          id: 'gi-assets-algorithm.src.NodesClustering.Component.NoDataAvailable',
          dm: '暂无数据'
        })
      });
    }
    return /*#__PURE__*/React.createElement("div", {
      className: "nodes-clustering-result-wrapper"
    }, /*#__PURE__*/React.createElement("span", {
      className: "intelligent-analysis-title nodes-clustering-result-title"
    }, $i18n.get({
      id: 'gi-assets-algorithm.src.NodesClustering.Component.AnalysisResults',
      dm: '分析结果'
    })), /*#__PURE__*/React.createElement(ClustersTable, {
      data: resData,
      clusterTitle: $i18n.get({
        id: 'gi-assets-algorithm.src.NodesClustering.Component.Classification',
        dm: '分类'
      }),
      focusNodeAndHighlightHull: focusNodeAndHighlightHull
    }));
  };
  var clearActiveState = function clearActiveState() {
    if (focusNodeId) {
      var focusNode = graph.findById(focusNodeId);
      if (focusNode.hasState('active')) {
        graph.setItemState(focusNodeId, 'active', false);
      }
    }
  };
  var focusNodeAndHighlightHull = function focusNodeAndHighlightHull(nodeId) {
    var focusClusterId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    clearActiveState();
    var node = graph.findById(nodeId);
    if (node) {
      graph.setItemState(node, 'active', true);
      setFocusNodeId(nodeId);
    }
  };
  var reset = function reset() {
    setResData({
      nodes: [],
      edges: []
    });
    setNodeClusteringAlgo(NodesClusteringAlgorithm.KMeans);
    setClusterK(2);
    clearActiveState();
    updateContext(function (draft) {
      draft.data = initData;
      draft.layout = prevLayout;
    });
  };
  useEffect(function () {
    if (!isEqual(data, prevData)) {
      // @ts-ignore
      setInitData(getInitData());
      // 源数据变化，清空当前结果
      setResData({
        nodes: [],
        edges: []
      });
      clearActiveState();
      updateContext(function (draft) {
        draft.layout = prevLayout;
      });
    }
    // @ts-ignore
    setPrevData(cloneDeep(data));
  }, [data, graph]);
  useEffect(function () {
    //@ts-ignore
    setInitData(getInitData());
    //@ts-ignore
    setPrevLayout(layout);
  }, []);
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-wrapper"
  }, /*#__PURE__*/React.createElement(Row, {
    justify: "space-between"
  }, /*#__PURE__*/React.createElement(Col, {
    span: 21
  }, /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-algo-title"
  }, /*#__PURE__*/React.createElement("h4", {
    className: "nodes-clustering-algo-title-name"
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.NodesclusteringalgorithmkmeansAlgorithm',
    dm: '{NodesClusteringAlgorithmKMeans}算法'
  }, {
    NodesClusteringAlgorithmKMeans: NodesClusteringAlgorithm.KMeans
  })), /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-algo-title-tip"
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.GatherNodesIntoKClusters',
    dm: '根据节点之间的距离将节点聚成K个簇'
  })))), /*#__PURE__*/React.createElement(Col, {
    span: 2,
    offset: 1,
    style: {
      lineHeight: '32px',
      textAlign: 'right'
    }
  }, /*#__PURE__*/React.createElement(ReloadOutlined, {
    onClick: reset
  }))), /*#__PURE__*/React.createElement("div", {
    className: "nodes-clustering-algo-body"
  }, /*#__PURE__*/React.createElement("span", null, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.SetTheKValue',
    dm: '设置 K 值'
  })), /*#__PURE__*/React.createElement(InputNumber, {
    min: 1,
    value: clusterK,
    style: {
      margin: '10px 20px'
    },
    onChange: function onChange(value) {
      return setClusterK(value);
    }
  })), /*#__PURE__*/React.createElement(Button, {
    type: "primary",
    style: {
      width: '100%',
      marginTop: '12px'
    },
    loading: loading,
    onClick: onAnalyse
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.NodesClustering.Component.Analysis',
    dm: '分析'
  })), renderResult()));
};
export default /*#__PURE__*/memo(NodesClustering);
